@@ -5,21 +5,21 @@ fn test() {
 		none # comment
 		None
 		# comment
-		none
+		:
 		koala
 		:
-			none
+			# comment
 		: # comment
-			none
+			# comment
 	").unwrap();
 	assert_eq!(t, [
 		Some("foo".into()),
-		None,
+		Some("none".into()),
 		Some("None".into()),
 		None,
 		Some("koala".into()),
-		None,
-		None,
+		Some("# comment".into()),
+		Some("# comment".into()),
 	])
 }
 
@@ -27,25 +27,35 @@ fn test() {
 fn dict() {
 	let t: std::collections::BTreeMap<String,Option<String>> = crate::from_bytes(b"
 		dog:
-			none # comment
+			# comment
 		fish: # comment
 
 
 		foo:
 			foo
-		koala: none
+		koala:
 		meerkat:
 			# foo
-			none
+			# bar
 		minx: # comment
-			none
 	").unwrap();
 	assert_eq!(t, std::array::IntoIter::new([
-		("dog".into(), None),
-		("fish".into(), Some("".into())),
+		("dog".into(), Some("# comment".into())),
+		("fish".into(), None),
 		("foo".into(), Some("foo".into())),
 		("koala".into(), None),
-		("meerkat".into(), Some("# foo\nnone".into())),
+		("meerkat".into(), Some("# foo\n# bar".into())),
 		("minx".into(), None),
 	]).collect())
 }
+
+#[test]
+fn two_word() {
+	let t: std::collections::BTreeMap<String,Option<String>> = crate::from_bytes(b"
+		dog:
+			none here
+	").unwrap();
+	assert_eq!(t, std::array::IntoIter::new([
+		("dog".into(), Some("none here".into())),
+	]).collect())
+}
